@@ -45,8 +45,10 @@ on_bus_acquired (GDBusConnection *connection,
                  const gchar     *name,
                  gpointer         user_data)
 {
-  if (connection != NULL)
-    the_daemon = goa_daemon_new ();
+  g_return_if_fail (G_IS_DBUS_CONNECTION (connection));
+  g_return_if_fail (name != NULL && name[0] != '\0');
+
+  the_daemon = goa_daemon_new (connection);
   g_debug ("Connected to the session bus");
 }
 
@@ -55,6 +57,9 @@ on_name_lost (GDBusConnection *connection,
               const gchar     *name,
               gpointer         user_data)
 {
+  g_return_if_fail (connection == NULL || G_IS_DBUS_CONNECTION (connection));
+  g_return_if_fail (name != NULL && name[0] != '\0');
+
   g_info ("Lost (or failed to acquire) the name %s on the session message bus", name);
   g_main_loop_quit (loop);
 }
@@ -64,6 +69,9 @@ on_name_acquired (GDBusConnection *connection,
                   const gchar     *name,
                   gpointer         user_data)
 {
+  g_return_if_fail (G_IS_DBUS_CONNECTION (connection));
+  g_return_if_fail (name != NULL && name[0] != '\0');
+
   g_debug ("Acquired the name %s on the session message bus", name);
 }
 
@@ -128,8 +136,8 @@ main (int    argc,
   g_clear_object (&the_daemon);
   if (name_owner_id != 0)
     g_bus_unown_name (name_owner_id);
-  g_clear_pointer (&loop, (GDestroyNotify) g_main_loop_unref);
-  g_clear_pointer (&opt_context, (GDestroyNotify) g_option_context_free);
+  g_clear_pointer (&loop, g_main_loop_unref);
+  g_clear_pointer (&opt_context, g_option_context_free);
 
   g_message ("goa-daemon version %s exiting", PACKAGE_VERSION);
 
