@@ -36,8 +36,10 @@
 
 #include "goakerberosidentitymanager.h"
 
-struct _GoaIdentityServicePrivate
+struct _GoaIdentityService
 {
+  GoaIdentityServiceManagerSkeleton  parent_instance;
+
   GDBusConnection          *connection;
   GDBusObjectManagerServer *object_manager_server;
   guint                     bus_id;
@@ -66,7 +68,6 @@ sign_in (GoaIdentityService     *self,
 G_DEFINE_TYPE_WITH_CODE (GoaIdentityService,
                          goa_identity_service,
                          GOA_IDENTITY_SERVICE_TYPE_MANAGER_SKELETON,
-                         G_ADD_PRIVATE (GoaIdentityService)
                          G_IMPLEMENT_INTERFACE (GOA_IDENTITY_SERVICE_TYPE_MANAGER,
                                                 identity_service_manager_interface_init));
 
@@ -113,7 +114,7 @@ export_identity (GoaIdentityService *self,
   g_dbus_object_skeleton_add_interface (object, interface);
   g_object_unref (interface);
 
-  g_dbus_object_manager_server_export (self->priv->object_manager_server, object);
+  g_dbus_object_manager_server_export (self->object_manager_server, object);
   g_object_unref (object);
 
   return object_path;
@@ -127,8 +128,7 @@ unexport_identity (GoaIdentityService *self,
 
   object_path = get_object_path_for_identity (self, identity);
 
-  g_dbus_object_manager_server_unexport (self->priv->object_manager_server,
-                                         object_path);
+  g_dbus_object_manager_server_unexport (self->object_manager_server, object_path);
   g_free (object_path);
 }
 
@@ -170,11 +170,9 @@ find_object_with_principal (GoaIdentityService *self,
 {
   GList      *objects;
   GList      *node;
-  GoaObject  *found_object;
+  GoaObject  *found_object = NULL;
 
-  objects = goa_client_get_accounts (self->priv->client);
-
-  found_object = NULL;
+  objects = goa_client_get_accounts (self->client);
   for (node = objects; node != NULL; node = node->next)
     {
       GoaObject *object = GOA_OBJECT (node->data);
@@ -336,15 +334,11 @@ goa_identity_service_handle_sign_in (GoaIdentityServiceManager *manager,
   GoaIdentityService     *self = GOA_IDENTITY_SERVICE (manager);
   GTask                  *operation_result;
   GoaIdentitySignInFlags  flags;
-  char                   *secret_key;
-  char                   *preauth_source;
-  gconstpointer           initial_password;
+  char                   *secret_key = NULL;
+  char                   *preauth_source = NULL;
+  gconstpointer           initial_password = NULL;
   GCancellable           *cancellable;
 
-  secret_key = NULL;
-  preauth_source = NULL;
-  initial_password = NULL;
-
   read_sign_in_details (manager, details, &flags, &secret_key, &preauth_source);
 
   if (secret_key != NULL)
@@ -356,7 +350,7 @@ goa_identity_service_handle_sign_in (GoaIdentityServiceManager *manager,
                              g_dbus_method_invocation_get_sender (invocation),
                              identifier);
 
-      secret_exchange = g_hash_table_lookup (self->priv->key_holders, key);
+      secret_exchange = g_hash_table_lookup (self->key_holders, key);
       g_free (key);
 
       if (secret_exchange == NULL)
@@ -505,7 +499,7 @@ goa_identity_service_handle_sign_out (GoaIdentityServiceManager *manager,
   GTask *task;
 
   task = g_task_new (self, NULL, (GAsyncReadyCallback) on_sign_out_handled, g_object_ref (invocation));
-  goa_identity_manager_get_identity (self->priv->identity_manager,
+  goa_identity_manager_get_identity (self->identity_manager,
                                      identifier,
                                      NULL,
                                      (GAsyncReadyCallback)
@@ -555,6 +549,7 @@ on_caller_watched (GDBusConnection    *connection,
   char                  *output_key;
 
   self = GOA_IDENTITY_SERVICE (g_task_get_source_object (operation_result));
+
   identifier = g_object_get_data (G_OBJECT (operation_result), "identifier");
   input_key = g_object_get_data (G_OBJECT (operation_result), "input-key");
 
@@ -570,9 +565,7 @@ on_caller_watched (GDBusConnection    *connection,
       return;
     }
 
-  g_hash_table_insert (self->priv->key_holders,
-                       g_strdup_printf ("%s %s", name_owner, identifier),
-                       secret_exchange);
+  g_hash_table_insert (self->key_holders, g_strdup_printf ("%s %s", name_owner, identifier), secret_exchange);
 
   output_key = gcr_secret_exchange_send (secret_exchange, NULL, 0);
   g_task_return_pointer (operation_result, output_key, g_free);
@@ -591,8 +584,8 @@ on_caller_vanished (GDBusConnection    *connection,
   cancellable = g_task_get_cancellable (operation_result);
   g_cancellable_cancel (cancellable);
 
-  g_hash_table_remove (self->priv->watched_client_connections, name);
-  g_hash_table_remove (self->priv->key_holders, name);
+  g_hash_table_remove (self->watched_client_connections, name);
+  g_hash_table_remove (self->key_holders, name);
 
 }
 
@@ -630,9 +623,7 @@ goa_identity_service_handle_exchange_secret_keys (GoaIdentityServiceManager *man
                                on_caller_vanished,
                                g_object_ref (operation_result),
                                g_object_unref);
-  g_hash_table_insert (self->priv->watched_client_connections,
-                       g_strdup (sender),
-                       GUINT_TO_POINTER (watch_id));
+  g_hash_table_insert (self->watched_client_connections, g_strdup (sender), GUINT_TO_POINTER (watch_id));
 
   g_object_unref (operation_result);
   return TRUE;
@@ -649,25 +640,15 @@ identity_service_manager_interface_init (GoaIdentityServiceManagerIface *interfa
 static void
 goa_identity_service_init (GoaIdentityService *self)
 {
-  self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
-                                            GOA_TYPE_IDENTITY_SERVICE,
-                                            GoaIdentityServicePrivate);
-
   g_debug ("GoaIdentityService: initializing");
-  self->priv->watched_client_connections = g_hash_table_new_full (g_str_hash,
-                                                                  g_str_equal,
-                                                                  g_free,
-                                                                  (GDestroyNotify)
-                                                                  g_bus_unwatch_name);
+  self->watched_client_connections = g_hash_table_new_full (g_str_hash,
+                                                            g_str_equal,
+                                                            g_free,
+                                                            (GDestroyNotify)
+                                                            g_bus_unwatch_name);
 
-  self->priv->key_holders = g_hash_table_new_full (g_str_hash,
-                                                   g_str_equal,
-                                                   g_free,
-                                                   g_object_unref);
-  self->priv->pending_temporary_account_results = g_hash_table_new_full (g_str_hash,
-                                                                         g_str_equal,
-                                                                         g_free,
-                                                                         g_object_unref);
+  self->key_holders = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_object_unref);
+  self->pending_temporary_account_results = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_object_unref);
 }
 
 static void
@@ -684,11 +665,11 @@ goa_identity_service_finalize (GObject *object)
 
   goa_identity_service_deactivate (self);
 
-  g_clear_object (&self->priv->identity_manager);
-  g_clear_object (&self->priv->object_manager_server);
-  g_clear_pointer (&self->priv->watched_client_connections, g_hash_table_unref);
-  g_clear_pointer (&self->priv->key_holders, g_hash_table_unref);
-  g_clear_pointer (&self->priv->pending_temporary_account_results, g_hash_table_unref);
+  g_clear_object (&self->identity_manager);
+  g_clear_object (&self->object_manager_server);
+  g_clear_pointer (&self->watched_client_connections, g_hash_table_unref);
+  g_clear_pointer (&self->key_holders, g_hash_table_unref);
+  g_clear_pointer (&self->pending_temporary_account_results, g_hash_table_unref);
 
   G_OBJECT_CLASS (goa_identity_service_parent_class)->finalize (object);
 }
@@ -734,8 +715,7 @@ on_identity_needs_renewal (GoaIdentityManager *identity_manager,
 
   g_debug ("GoaIdentityService: identity %s needs renewal", principal);
 
-  goa_identity_manager_renew_identity (GOA_IDENTITY_MANAGER
-                                       (self->priv->identity_manager),
+  goa_identity_manager_renew_identity (GOA_IDENTITY_MANAGER (self->identity_manager),
                                        identity,
                                        NULL,
                                        (GAsyncReadyCallback)
@@ -796,7 +776,7 @@ add_temporary_account_as_fedora_add_account (GObject *source_object, GAsyncResul
 
   g_debug ("Created account for identity with object path %s", object_path);
 
-  object_manager = goa_client_get_object_manager (self->priv->client);
+  object_manager = goa_client_get_object_manager (self->client);
   object = GOA_OBJECT (g_dbus_object_manager_get_object (object_manager, object_path));
   if (object == NULL)
     {
@@ -847,7 +827,7 @@ add_temporary_account_as_fedora (GoaIdentityService *self,
 
   g_variant_builder_add (&details, "{ss}", "TicketingEnabled", "true");
 
-  manager = goa_client_get_manager (self->priv->client);
+  manager = goa_client_get_manager (self->client);
   goa_manager_call_add_account (manager,
                                 GOA_FEDORA_NAME,
                                 principal,
@@ -900,7 +880,7 @@ add_temporary_account_as_kerberos_add_account (GObject *source_object, GAsyncRes
 
   g_debug ("Created account for identity with object path %s", object_path);
 
-  object_manager = goa_client_get_object_manager (self->priv->client);
+  object_manager = goa_client_get_object_manager (self->client);
   object = GOA_OBJECT (g_dbus_object_manager_get_object (object_manager, object_path));
   if (object == NULL)
     {
@@ -954,7 +934,7 @@ add_temporary_account_as_kerberos (GoaIdentityService *self,
 
   g_variant_builder_add (&details, "{ss}", "TicketingEnabled", "true");
 
-  manager = goa_client_get_manager (self->priv->client);
+  manager = goa_client_get_manager (self->client);
   goa_manager_call_add_account (manager,
                                 GOA_KERBEROS_NAME,
                                 principal,
@@ -999,7 +979,7 @@ on_temporary_account_added_as_kerberos (GObject *source_object, GAsyncResult *re
   error = NULL;
 
   principal = goa_identity_get_identifier (identity);
-  g_hash_table_remove (self->priv->pending_temporary_account_results, principal);
+  g_hash_table_remove (self->pending_temporary_account_results, principal);
 
   object = add_temporary_account_as_kerberos_finish (self, result, &error);
   if (error != NULL)
@@ -1048,7 +1028,7 @@ on_temporary_account_added_as_fedora (GObject *source_object, GAsyncResult *resu
     }
 
   principal = goa_identity_get_identifier (identity);
-  g_hash_table_remove (self->priv->pending_temporary_account_results, principal);
+  g_hash_table_remove (self->pending_temporary_account_results, principal);
 
   ensure_account_credentials (self, object);
 
@@ -1065,7 +1045,7 @@ add_temporary_account (GoaIdentityService *self,
   gchar *realm = NULL;
 
   principal = goa_identity_get_identifier (identity);
-  if (g_hash_table_contains (self->priv->pending_temporary_account_results, principal))
+  if (g_hash_table_contains (self->pending_temporary_account_results, principal))
     {
       g_debug ("GoaIdentityService: would add temporary identity %s, but it's already pending", principal);
       return;
@@ -1078,9 +1058,7 @@ add_temporary_account (GoaIdentityService *self,
 
   g_debug ("GoaIdentityService: asking to sign back in");
 
-  g_hash_table_insert (self->priv->pending_temporary_account_results,
-                       g_strdup (principal),
-                       g_object_ref (identity));
+  g_hash_table_insert (self->pending_temporary_account_results, g_strdup (principal), g_object_ref (identity));
 
   realm = goa_kerberos_identity_get_realm_name (GOA_KERBEROS_IDENTITY (identity));
   if (g_strcmp0 (realm, GOA_FEDORA_REALM) == 0)
@@ -1264,7 +1242,7 @@ on_password_system_prompt_answered (GcrPrompt           *prompt,
       goa_identity_inquiry_answer_query (inquiry, query, password);
     }
 
-  close_system_prompt (self->priv->identity_manager, identity, request);
+  close_system_prompt (self->identity_manager, identity, request);
   system_prompt_request_free (request);
 }
 
@@ -1286,7 +1264,7 @@ query_user (GoaIdentityService *self,
 
   gcr_prompt_set_title (prompt, _("Log In to Realm"));
 
-  name = goa_identity_manager_name_identity (self->priv->identity_manager, identity);
+  name = goa_identity_manager_name_identity (self->identity_manager, identity);
 
   description =
     g_strdup_printf (_("The network realm %s needs some information to sign you in."),
@@ -1307,10 +1285,7 @@ query_user (GoaIdentityService *self,
                                        query,
                                        cancellable);
 
-  g_signal_connect (self->priv->identity_manager,
-                    "identity-refreshed",
-                    G_CALLBACK (close_system_prompt),
-                    request);
+  g_signal_connect (self->identity_manager, "identity-refreshed", G_CALLBACK (close_system_prompt), request);
 
   query_mode = goa_identity_query_get_mode (inquiry, query);
 
@@ -1456,13 +1431,9 @@ sign_in (GoaIdentityService     *self,
   operation_result = g_task_new (self, cancellable, callback, user_data);
   g_task_set_task_data (operation_result, user_data, NULL);
 
-  g_signal_connect_object (self->priv->identity_manager,
-                           "identity-refreshed",
-                           G_CALLBACK (cancel_sign_in),
-                           operation_result,
-                           0);
+  g_signal_connect_object (self->identity_manager, "identity-refreshed", G_CALLBACK (cancel_sign_in), operation_result, 0);
 
-  goa_identity_manager_sign_identity_in (self->priv->identity_manager,
+  goa_identity_manager_sign_identity_in (self->identity_manager,
                                          identifier,
                                          initial_password,
                                          preauth_source,
@@ -1678,7 +1649,7 @@ on_account_interface_removed (GDBusObjectManager *manager,
   g_debug ("Kerberos account %s was disabled and should now be signed out", account_identity);
 
   task = g_task_new (self, NULL, (GAsyncReadyCallback) on_sign_out_for_account_change_done, NULL);
-  goa_identity_manager_get_identity (self->priv->identity_manager,
+  goa_identity_manager_get_identity (self->identity_manager,
                                      account_identity,
                                      NULL,
                                      (GAsyncReadyCallback)
@@ -1696,15 +1667,12 @@ on_identities_listed (GoaIdentityManager *manager,
   GError *error = NULL;
   GList *identities, *node;
 
-  g_signal_connect (self->priv->identity_manager, "identity-added", G_CALLBACK (on_identity_added), self);
-  g_signal_connect (self->priv->identity_manager, "identity-removed", G_CALLBACK (on_identity_removed), self);
-  g_signal_connect (self->priv->identity_manager, "identity-refreshed", G_CALLBACK (on_identity_refreshed), self);
-  g_signal_connect (self->priv->identity_manager,
-                    "identity-needs-renewal",
-                    G_CALLBACK (on_identity_needs_renewal),
-                    self);
-  g_signal_connect (self->priv->identity_manager, "identity-expiring", G_CALLBACK (on_identity_expiring), self);
-  g_signal_connect (self->priv->identity_manager, "identity-expired", G_CALLBACK (on_identity_expired), self);
+  g_signal_connect (self->identity_manager, "identity-added", G_CALLBACK (on_identity_added), self);
+  g_signal_connect (self->identity_manager, "identity-removed", G_CALLBACK (on_identity_removed), self);
+  g_signal_connect (self->identity_manager, "identity-refreshed", G_CALLBACK (on_identity_refreshed), self);
+  g_signal_connect (self->identity_manager, "identity-needs-renewal", G_CALLBACK (on_identity_needs_renewal), self);
+  g_signal_connect (self->identity_manager, "identity-expiring", G_CALLBACK (on_identity_expiring), self);
+  g_signal_connect (self->identity_manager, "identity-expired", G_CALLBACK (on_identity_expired), self);
 
   identities = goa_identity_manager_list_identities_finish (manager, result, &error);
 
@@ -1750,12 +1718,12 @@ ensure_credentials_for_accounts (GoaIdentityService *self)
   GList      *accounts;
   GList      *node;
 
-  object_manager = goa_client_get_object_manager (self->priv->client);
+  object_manager = goa_client_get_object_manager (self->client);
 
   g_signal_connect (object_manager, "interface-added", G_CALLBACK (on_account_interface_added), self);
   g_signal_connect (object_manager, "interface-removed", G_CALLBACK (on_account_interface_removed), self);
 
-  accounts = goa_client_get_accounts (self->priv->client);
+  accounts = goa_client_get_accounts (self->client);
 
   for (node = accounts; node != NULL; node = node->next)
     {
@@ -1794,23 +1762,23 @@ on_got_client (GoaClient          *client,
 
   error = NULL;
 
-  self->priv->client = goa_client_new_finish (result, &error);
+  self->client = goa_client_new_finish (result, &error);
 
-  if (self->priv->client == NULL)
+  if (self->client == NULL)
     {
       g_warning ("Could not create client: %s", error->message);
       goto out;
     }
 
-  self->priv->identity_manager = goa_kerberos_identity_manager_new (NULL, &error);
+  self->identity_manager = goa_kerberos_identity_manager_new (NULL, &error);
 
-  if (self->priv->identity_manager == NULL)
+  if (self->identity_manager == NULL)
     {
       g_warning ("Could not create identity manager: %s", error->message);
       goto out;
     }
 
-  goa_identity_manager_list_identities (self->priv->identity_manager,
+  goa_identity_manager_list_identities (self->identity_manager,
                                         NULL,
                                         (GAsyncReadyCallback)
                                         on_identities_listed,
@@ -1829,13 +1797,10 @@ on_session_bus_acquired (GDBusConnection    *connection,
 {
   g_debug ("GoaIdentityService: Connected to session bus");
 
-  if (self->priv->connection == NULL)
+  if (self->connection == NULL)
   {
-    self->priv->connection = g_object_ref (connection);
-
-    g_dbus_object_manager_server_set_connection (self->priv->object_manager_server,
-                                                 self->priv->connection);
-
+    self->connection = g_object_ref (connection);
+    g_dbus_object_manager_server_set_connection (self->object_manager_server, self->connection);
     goa_client_new (NULL,
                     (GAsyncReadyCallback)
                     on_got_client,
@@ -1871,26 +1836,24 @@ goa_identity_service_activate (GoaIdentityService   *self,
 
   g_debug ("GoaIdentityService: Activating identity service");
 
-  self->priv->object_manager_server =
-    g_dbus_object_manager_server_new ("/org/gnome/Identity");
+  self->object_manager_server = g_dbus_object_manager_server_new ("/org/gnome/Identity");
 
   object = goa_identity_service_object_skeleton_new ("/org/gnome/Identity/Manager");
   goa_identity_service_object_skeleton_set_manager (object,
                                                     GOA_IDENTITY_SERVICE_MANAGER (self));
 
-  g_dbus_object_manager_server_export (self->priv->object_manager_server,
-                                       G_DBUS_OBJECT_SKELETON (object));
+  g_dbus_object_manager_server_export (self->object_manager_server, G_DBUS_OBJECT_SKELETON (object));
   g_object_unref (object);
 
-  self->priv->bus_id = g_bus_own_name (G_BUS_TYPE_SESSION,
-                                       "org.gnome.Identity",
-                                       G_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT |
-                                       G_BUS_NAME_OWNER_FLAGS_REPLACE,
-                                       (GBusAcquiredCallback) on_session_bus_acquired,
-                                       (GBusNameAcquiredCallback) on_name_acquired,
-                                       (GBusNameVanishedCallback) on_name_lost,
-                                       self,
-                                       NULL);
+  self->bus_id = g_bus_own_name (G_BUS_TYPE_SESSION,
+                                 "org.gnome.Identity",
+                                 G_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT |
+                                 G_BUS_NAME_OWNER_FLAGS_REPLACE,
+                                 (GBusAcquiredCallback) on_session_bus_acquired,
+                                 (GBusNameAcquiredCallback) on_name_acquired,
+                                 (GBusNameVanishedCallback) on_name_lost,
+                                 self,
+                                 NULL);
 
   return TRUE;
 }
@@ -1900,17 +1863,17 @@ goa_identity_service_deactivate (GoaIdentityService *self)
 {
   g_debug ("GoaIdentityService: Deactivating identity service");
 
-  if (self->priv->identity_manager != NULL)
+  if (self->identity_manager != NULL)
     {
       g_signal_handlers_disconnect_by_func (self, on_identity_needs_renewal, self);
       g_signal_handlers_disconnect_by_func (self, on_identity_expiring, self);
       g_signal_handlers_disconnect_by_func (self, on_identity_expired, self);
-      g_clear_object (&self->priv->identity_manager);
+      g_clear_object (&self->identity_manager);
     }
 
-  g_clear_object (&self->priv->object_manager_server);
-  g_clear_object (&self->priv->connection);
-  g_clear_object (&self->priv->client);
+  g_clear_object (&self->object_manager_server);
+  g_clear_object (&self->connection);
+  g_clear_object (&self->client);
 }
 
 static void
